@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,9 +20,11 @@
 #ifndef WEECHAT_DEBUG_H
 #define WEECHAT_DEBUG_H
 
+#include <sys/time.h>
+
 struct t_gui_window_tree;
 
-extern void debug_sigsegv ();
+extern void debug_sigsegv_cb ();
 extern void debug_windows_tree ();
 extern void debug_memory ();
 extern void debug_hdata ();
