@@ -1,7 +1,7 @@
 /*
  * gui-bar-item.c - bar item functions (used by all GUI)
  *
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -73,7 +73,7 @@ char *gui_bar_items_default_for_bars[][2] =
   { GUI_BAR_DEFAULT_NAME_STATUS,
     "[time],[buffer_last_number],[buffer_plugin],buffer_number+:+"
     "buffer_name+(buffer_modes)+{buffer_nicklist_count}+buffer_zoom+"
-    "buffer_filter,scroll,[lag],[hotlist],completion" },
+    "buffer_filter,scroll,[lag],[hotlist],[typing],completion" },
   { GUI_BAR_DEFAULT_NAME_NICKLIST,
     "buffer_nicklist" },
   { NULL,
@@ -990,7 +990,7 @@ gui_bar_item_time_cb (const void *pointer, void *data,
                       struct t_gui_buffer *buffer,
                       struct t_hashtable *extra_info)
 {
-    char text_time[128], text_time2[128];
+    char text_time[128], text_time2[256];
 
     /* make C compiler happy */
     (void) pointer;
