@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -206,6 +206,7 @@ struct t_gui_buffer
 
     /* hotlist */
     struct t_gui_hotlist *hotlist;     /* hotlist entry for buffer          */
+    struct t_gui_hotlist *hotlist_removed; /* hotlist that can be restored  */
     struct t_hashtable *hotlist_max_level_nicks; /* max hotlist level for   */
                                                  /* some nicks              */
 
@@ -255,6 +256,11 @@ extern int gui_buffer_search_notify (const char *notify);
 extern const char *gui_buffer_get_plugin_name (struct t_gui_buffer *buffer);
 extern const char *gui_buffer_get_short_name (struct t_gui_buffer *buffer);
 extern void gui_buffer_build_full_name (struct t_gui_buffer *buffer);
+extern void gui_buffer_local_var_add (struct t_gui_buffer *buffer,
+                                      const char *name,
+                                      const char *value);
+extern void gui_buffer_local_var_remove (struct t_gui_buffer *buffer,
+                                         const char *name);
 extern void gui_buffer_notify_set_all ();
 extern void gui_buffer_input_buffer_init (struct t_gui_buffer *buffer);
 extern int gui_buffer_is_reserved_name (const char *name);
