@@ -1,7 +1,7 @@
 /*
  * buflist-bar-item.c - bar item for buflist plugin
  *
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -103,16 +103,23 @@ buflist_bar_item_get_index_with_pointer (struct t_gui_bar_item *item)
 
 /*
  * Updates buflist bar item if buflist is enabled (or if force argument is 1).
+ *
+ * If force == 1, all used items are refreshed
+ *   (according to option buflist.look.use_items).
+ * If force == 2, all items are refreshed.
  */
 
 void
 buflist_bar_item_update (int force)
 {
-    int i;
+    int i, num_items;
 
     if (force || weechat_config_boolean (buflist_config_look_enabled))
     {
-        for (i = 0; i < BUFLIST_BAR_NUM_ITEMS; i++)
+        num_items = (force == 2) ?
+            BUFLIST_BAR_NUM_ITEMS :
+            weechat_config_integer (buflist_config_look_use_items);
+        for (i = 0; i < num_items; i++)
         {
             weechat_bar_item_update (buflist_bar_item_get_name (i));
         }
@@ -305,7 +312,7 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
     const char *hotlist_priority[4] = { "low", "message", "private",
                                         "highlight" };
     const char indent_empty[1] = { '\0' };
-    const char *ptr_lag, *ptr_item_name;
+    const char *ptr_lag, *ptr_item_name, *ptr_tls_version;
     int item_index, num_buffers, is_channel, is_private;
     int i, j, length_max_number, current_buffer, number, prev_number, priority;
     int rc, count, line_number, line_number_current_buffer;
@@ -318,14 +325,17 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
     if (!weechat_config_boolean (buflist_config_look_enabled))
         return NULL;
 
+    item_index = (int)((unsigned long)pointer);
+
+    if (item_index + 1 > weechat_config_integer (buflist_config_look_use_items))
+        return NULL;
+
     prev_number = -1;
     line_number = 0;
     line_number_current_buffer = 0;
 
     buflist = weechat_string_dyn_alloc (256);
 
-    item_index = (int)((unsigned long)pointer);
-
     weechat_hashtable_set (buflist_hashtable_pointers, "bar_item", item);
     if (window)
         weechat_hashtable_set (buflist_hashtable_pointers, "window", window);
@@ -586,6 +596,14 @@ buflist_bar_item_buflist_cb (const void *pointer, void *data,
                                    "format_lag", "");
         }
 
+        /* tls version */
+        ptr_tls_version = weechat_buffer_get_string (ptr_buffer, "localvar_tls_version");
+        weechat_hashtable_set (
+            buflist_hashtable_extra_vars,
+            "format_tls_version",
+            (ptr_tls_version && ptr_tls_version[0]) ?
+            weechat_config_string (buflist_config_format_tls_version) : "");
+
         /* check condition: if false, the buffer is not displayed */
         condition = weechat_string_eval_expression (
             weechat_config_string (buflist_config_look_display_conditions),
