@@ -1,7 +1,7 @@
 /*
  * buflist.c - Bar with list of buffers
  *
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -38,7 +38,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Buffers list"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
-WEECHAT_PLUGIN_PRIORITY(9000);
+WEECHAT_PLUGIN_PRIORITY(10000);
 
 struct t_weechat_plugin *weechat_buflist_plugin = NULL;
 
@@ -57,10 +57,13 @@ struct t_hdata *buflist_hdata_bar_window = NULL;
 void
 buflist_add_bar ()
 {
-    weechat_bar_new (BUFLIST_BAR_NAME, "off", "0", "root", "", "left",
-                     "columns_vertical", "vertical", "0", "0",
-                     "default", "default", "default", "default", "on",
-                     BUFLIST_BAR_ITEM_NAME);
+    weechat_bar_new (
+        BUFLIST_BAR_NAME,
+        (weechat_config_boolean (buflist_config_look_enabled)) ? "off" : "on",
+        "0", "root", "", "left",
+        "columns_vertical", "vertical", "0", "0",
+        "default", "default", "default", "default", "on",
+        BUFLIST_BAR_ITEM_NAME);
 }
 
 /*
@@ -143,7 +146,7 @@ buflist_buffer_get_irc_pointers (struct t_gui_buffer *buffer,
  * For example with such list of merged buffers:
  *
  *     weechat
- *     freenode
+ *     libera
  *     oftc      (active)
  *     test
  *     another
@@ -154,7 +157,7 @@ buflist_buffer_get_irc_pointers (struct t_gui_buffer *buffer,
  *     test
  *     another
  *     weechat
- *     freenode
+ *     libera
  *
  * Returns:
  *   -1: buffer1 must be sorted before buffer2
@@ -268,7 +271,7 @@ buflist_compare_buffers (void *data, struct t_arraylist *arraylist,
             else
             {
                 rc = weechat_hdata_compare (buflist_hdata_hotlist,
-                                            pointer1, pointer2,
+                                            ptr_hotlist1, ptr_hotlist2,
                                             ptr_field + 8,
                                             case_sensitive);
             }
@@ -464,8 +467,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 
     buflist_command_init ();
 
-    if (weechat_config_boolean (buflist_config_look_enabled))
-        buflist_add_bar ();
+    buflist_add_bar ();
 
     buflist_bar_item_update (0);
 
