@@ -1,7 +1,7 @@
 /*
  * fifo.c - fifo plugin for WeeChat: remote control with FIFO pipe
  *
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -42,7 +42,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("FIFO pipe for remote control"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
-WEECHAT_PLUGIN_PRIORITY(8000);
+WEECHAT_PLUGIN_PRIORITY(9000);
 
 struct t_weechat_plugin *weechat_fifo_plugin = NULL;
 #define weechat_plugin weechat_fifo_plugin
@@ -65,16 +65,26 @@ void
 fifo_create ()
 {
     struct stat st;
+    struct t_hashtable *options;
 
     if (!weechat_config_boolean (fifo_config_file_enabled))
         return;
 
     if (!fifo_filename)
     {
-        /* replace %h and "~", evaluate path */
+        /* evaluate path */
+        options = weechat_hashtable_new (
+            32,
+            WEECHAT_HASHTABLE_STRING,
+            WEECHAT_HASHTABLE_STRING,
+            NULL, NULL);
+        if (options)
+            weechat_hashtable_set (options, "directory", "runtime");
         fifo_filename = weechat_string_eval_path_home (
             weechat_config_string (fifo_config_file_path),
-            NULL, NULL, NULL);
+            NULL, NULL, options);
+        if (options)
+            weechat_hashtable_free (options);
     }
 
     if (!fifo_filename)
