@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -56,7 +56,8 @@ struct t_irc_channel;
 /* list of supported capabilities (for completion in command /cap) */
 #define IRC_COMMAND_CAP_SUPPORTED_COMPLETION \
     "account-notify|away-notify|cap-notify|chghost|extended-join|"      \
-    "invite-notify|multi-prefix|server-time|userhost-in-names|%*"
+    "invite-notify|message-tags|multi-prefix|server-time|setname|"      \
+    "userhost-in-names"
 
 /* list of supported CTCPs (for completion in command /ctcp) */
 #define IRC_COMMAND_CTCP_SUPPORTED_COMPLETION \
