@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -99,10 +99,12 @@ extern struct t_config_option *irc_config_look_color_nicks_in_nicklist;
 extern struct t_config_option *irc_config_look_color_nicks_in_server_messages;
 extern struct t_config_option *irc_config_look_color_pv_nick_like_channel;
 extern struct t_config_option *irc_config_look_ctcp_time_format;
+extern struct t_config_option *irc_config_look_display_account_message;
 extern struct t_config_option *irc_config_look_display_away;
 extern struct t_config_option *irc_config_look_display_ctcp_blocked;
 extern struct t_config_option *irc_config_look_display_ctcp_reply;
 extern struct t_config_option *irc_config_look_display_ctcp_unknown;
+extern struct t_config_option *irc_config_look_display_extended_join;
 extern struct t_config_option *irc_config_look_display_host_join;
 extern struct t_config_option *irc_config_look_display_host_join_local;
 extern struct t_config_option *irc_config_look_display_host_quit;
@@ -136,6 +138,8 @@ extern struct t_config_option *irc_config_look_part_closes_buffer;
 extern struct t_config_option *irc_config_look_pv_buffer;
 extern struct t_config_option *irc_config_look_pv_tags;
 extern struct t_config_option *irc_config_look_raw_messages;
+extern struct t_config_option *irc_config_look_typing_status_nicks;
+extern struct t_config_option *irc_config_look_typing_status_self;
 extern struct t_config_option *irc_config_look_server_buffer;
 extern struct t_config_option *irc_config_look_smart_filter;
 extern struct t_config_option *irc_config_look_smart_filter_account;
@@ -154,6 +158,9 @@ extern struct t_config_option *irc_config_color_item_channel_modes;
 extern struct t_config_option *irc_config_color_item_lag_counting;
 extern struct t_config_option *irc_config_color_item_lag_finished;
 extern struct t_config_option *irc_config_color_item_nick_modes;
+extern struct t_config_option *irc_config_color_item_tls_version_deprecated;
+extern struct t_config_option *irc_config_color_item_tls_version_insecure;
+extern struct t_config_option *irc_config_color_item_tls_version_ok;
 extern struct t_config_option *irc_config_color_message_account;
 extern struct t_config_option *irc_config_color_message_chghost;
 extern struct t_config_option *irc_config_color_message_join;
