@@ -1,7 +1,7 @@
 /*
  * irc.c - IRC (Internet Relay Chat) plugin for WeeChat
  *
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -42,6 +42,8 @@
 #include "irc-raw.h"
 #include "irc-redirect.h"
 #include "irc-server.h"
+#include "irc-tag.h"
+#include "irc-typing.h"
 #include "irc-upgrade.h"
 
 
@@ -145,13 +147,14 @@ irc_signal_upgrade_cb (const void *pointer, void *data,
     {
         weechat_printf (
             NULL,
-            /* TRANSLATORS: "%s" after "%d" is "server" or "servers" */
-            _("%s%s: disconnected from %d %s (SSL connection not supported "
-              "with upgrade)"),
+            NG_("%s%s: disconnected from %d server "
+                "(SSL connection not supported with upgrade)",
+                "%s%s: disconnected from %d servers "
+                "(SSL connection not supported with upgrade)",
+                ssl_disconnected),
             weechat_prefix ("error"),
             IRC_PLUGIN_NAME,
-            ssl_disconnected,
-            NG_("server", "servers", ssl_disconnected));
+            ssl_disconnected);
     }
 
     return WEECHAT_RC_OK;
@@ -198,6 +201,8 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
                          &irc_server_xfer_send_accept_resume_cb, NULL, NULL);
     weechat_hook_signal ("irc_input_send",
                          &irc_input_send_cb, NULL, NULL);
+    weechat_hook_signal ("typing_self_*",
+                         &irc_typing_signal_typing_self_cb, NULL, NULL);
 
     /* hook hsignals for redirection */
     weechat_hook_hsignal ("irc_redirect_pattern",
@@ -212,6 +217,10 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
                            &irc_color_modifier_cb, NULL, NULL);
     weechat_hook_modifier ("irc_color_decode_ansi",
                            &irc_color_modifier_cb, NULL, NULL);
+    weechat_hook_modifier ("irc_tag_escape_value",
+                           &irc_tag_modifier_cb, NULL, NULL);
+    weechat_hook_modifier ("irc_tag_unescape_value",
+                           &irc_tag_modifier_cb, NULL, NULL);
 
     /* hook completions */
     irc_completion_init ();
