@@ -1,7 +1,7 @@
 /*
  * logger.c - logger plugin for WeeChat: save buffer lines to disk files
  *
- * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -47,7 +47,7 @@ WEECHAT_PLUGIN_DESCRIPTION(N_("Log buffers to files"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
-WEECHAT_PLUGIN_PRIORITY(14000);
+WEECHAT_PLUGIN_PRIORITY(15000);
 
 struct t_weechat_plugin *weechat_logger_plugin = NULL;
 
@@ -59,8 +59,7 @@ struct t_hook *logger_hook_print = NULL;
  * Gets logger file path option.
  *
  * Special vars are replaced:
- *   - "%h" (at beginning of string): WeeChat home
- *   - "~": user home
+ *   - with call to function string_eval_path_home
  *   - date/time specifiers (see man strftime)
  *
  * Note: result must be freed after use.
@@ -73,13 +72,23 @@ logger_get_file_path ()
     int length;
     time_t seconds;
     struct tm *date_tmp;
+    struct t_hashtable *options;
 
     path = NULL;
     path2 = NULL;
 
-    /* replace %h and "~", evaluate path */
+    /* evaluate path */
+    options = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL, NULL);
+    if (options)
+        weechat_hashtable_set (options, "directory", "data");
     path = weechat_string_eval_path_home (
-        weechat_config_string (logger_config_file_path), NULL, NULL, NULL);
+        weechat_config_string (logger_config_file_path), NULL, NULL, options);
+    if (options)
+        weechat_hashtable_free (options);
     if (!path)
         goto end;
 
@@ -394,7 +403,7 @@ end:
 char *
 logger_get_filename (struct t_gui_buffer *buffer)
 {
-    char *res, *mask_expanded, *file_path, *dir_separator, *weechat_dir;
+    char *res, *mask_expanded, *file_path, *dir_separator;
     const char *mask;
     int length;
 
@@ -405,12 +414,6 @@ logger_get_filename (struct t_gui_buffer *buffer)
     dir_separator = weechat_info_get ("dir_separator", "");
     if (!dir_separator)
         return NULL;
-    weechat_dir = weechat_info_get ("weechat_dir", "");
-    if (!weechat_dir)
-    {
-        free (dir_separator);
-        return NULL;
-    }
 
     /* get filename mask for buffer */
     mask = logger_get_mask_for_buffer (buffer);
@@ -423,7 +426,6 @@ logger_get_filename (struct t_gui_buffer *buffer)
             weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
             weechat_buffer_get_string (buffer, "name"));
         free (dir_separator);
-        free (weechat_dir);
         return NULL;
     }
 
@@ -449,7 +451,6 @@ logger_get_filename (struct t_gui_buffer *buffer)
 
 end:
     free (dir_separator);
-    free (weechat_dir);
     if (mask_expanded)
         free (mask_expanded);
     if (file_path)
